Welcome to ClientVPS Mirrors

Help for package nbconvertR
Type: Package
Title: Vignette Engine Wrapping Jupyter Notebooks
Version: 1.3.2
Date: 2019-11-26
Author: Philipp Angerer
Maintainer: Philipp Angerer <philipp.angerer@helmholtz-muenchen.de>
Description: Calls the 'Jupyter' script 'nbconvert' to create vignettes from notebooks. Those notebooks ('.ipynb' files) are files containing rich text, code, and its output. Code cells can be edited and evaluated interactively. See https://jupyter.org/ for more information.
License: GPL-3
SystemRequirements: pandoc, jupyter, jupyter nbconvert ("nbconvert" python package), pywin32 (on windows)
Encoding: UTF-8
RoxygenNote: 7.0.0
Suggests: testthat
NeedsCompilation: no
Packaged: 2019-11-26 22:43:10 UTC; phil
Repository: CRAN
Date/Publication: 2019-11-27 15:30:02 UTC

Jupyter/IPython Notebook Conversion

Description

An R interface for using Jupyter/IPython system calls to convert .ipynb notebooks unsing meta information. When passed "<filename>.ipynbmeta" it will convert "<filename>.ipynb" to "<filename>.<ext>".

Usage

nbconvert(
  file,
  fmt = c("html", "latex", "markdown", "pdf", "rst", "script", "slides"),
  quiet = TRUE,
  ...
)

nbconvert_html(file, quiet = TRUE, ...)
nbconvert_latex(file, quiet = TRUE, ...)
nbconvert_markdown(file, quiet = TRUE, ...)
nbconvert_pdf(file, quiet = TRUE, ...)
nbconvert_rst(file, quiet = TRUE, ...)
nbconvert_script(file, quiet = TRUE, ...)
nbconvert_slides(file, quiet = TRUE, ...)

Arguments

file

A file with a .ipynbmeta extension that contains vignette metadata lines

fmt

A format supported by nbconvert. "script" will create an .r file, and "slides" a reveal.js-powered html presentation.

quiet

Suppress command output if TRUE (the output will always be shown on error)

...

Ignored for now

Details

Apart from the standard %\VignetteIndexEntry{<name>} and %\VignetteEngine{<namespace>::<name>} directives, it also understands:

  1. %\VignetteTemplate{<format>}{<filename>}, which will pass a --template parameter to nbconvert

  2. %\VignettePreprocessors{<format>}{<module>.<Preproc>[, ...]}, which will pass --<Format>Exporter.preprocessors=["<module>.<Preproc>",...] to nbconvert.

Value

The filename of the resulting document, script or presentation

Examples

## Not run: 
path <- system.file('doc/test-vignette.ipynbmeta', package = 'nbconvertR')
nbconvert(path, 'pdf')

## End(Not run)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.